Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1632)

Unified Diff: chrome/browser/extensions/api/extension_action/extension_action_api_constants.h

Issue 11638022: Consolidate [BrowserAction,PageAction,ScriptBadge]API into ExtensionActionAPI (Closed) Base URL: http://git.chromium.org/chromium/src.git@dc_unref_script_badge
Patch Set: Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/extension_action/extension_action_api_constants.h
diff --git a/chrome/browser/extensions/api/extension_action/extension_page_actions_api_constants.h b/chrome/browser/extensions/api/extension_action/extension_action_api_constants.h
similarity index 67%
rename from chrome/browser/extensions/api/extension_action/extension_page_actions_api_constants.h
rename to chrome/browser/extensions/api/extension_action/extension_action_api_constants.h
index 5f3ad9f42134bc61b432444c3a3dfd0e22451a1b..343cd62c56ca3da588f147823f0d5a454d75a863 100644
--- a/chrome/browser/extensions/api/extension_action/extension_page_actions_api_constants.h
+++ b/chrome/browser/extensions/api/extension_action/extension_action_api_constants.h
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// Constants used for the Page Actions API.
Yoyo Zhou 2012/12/19 23:30:52 I would leave this file alone if it's only being u
Devlin 2012/12/20 19:43:20 Done. And cool that we can rid of the deprecated c
-#ifndef CHROME_BROWSER_EXTENSIONS_API_EXTENSION_ACTION_EXTENSION_PAGE_ACTIONS_API_CONSTANTS_H_
-#define CHROME_BROWSER_EXTENSIONS_API_EXTENSION_ACTION_EXTENSION_PAGE_ACTIONS_API_CONSTANTS_H_
+#ifndef CHROME_BROWSER_EXTENSIONS_API_EXTENSION_ACTION_EXTENSION_ACTION_API_CONSTANTS_H_
+#define CHROME_BROWSER_EXTENSIONS_API_EXTENSION_ACTION_EXTENSION_ACTION_API_CONSTANTS_H_
-namespace extension_page_actions_api_constants {
+namespace extension_action_api_constants {
// Keys.
extern const char kTabIdKey[];
@@ -15,6 +15,6 @@ extern const char kUrlKey[];
extern const char kTitleKey[];
extern const char kButtonKey[];
-}; // namespace extension_page_actions_api_constants
+}; // namespace extension_action_api_constants
-#endif // CHROME_BROWSER_EXTENSIONS_API_EXTENSION_ACTION_EXTENSION_PAGE_ACTIONS_API_CONSTANTS_H_
+#endif // CHROME_BROWSER_EXTENSIONS_API_EXTENSION_ACTION_EXTENSION_ACTION_API_CONSTANTS_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// Constants used for the Page Actions API.
+// Constants used for the Extension Action API.
Yoyo Zhou 2012/12/19 23:30:52 I would leave this file alone if it's only being u
Devlin 2012/12/20 19:43:20 Done. And cool that we can rid of the deprecated c